extract a sicd chip utility (sarpy.utils.chip_sicd)
===================================================

.. automodule:: sarpy.utils.chip_sicd
    :members:
    :show-inheritance:
    :inherited-members:
